import { BlockAtom, SylApi, SylController, SylPlugin } from '@syllepsis/adapter';
import { DOMOutputSpec, Node } from 'prosemirror-model';
import { IUserAttrsConfig } from '../../utils';
interface IAudioAttrs {
    src: string;
    title: string;
    type: string;
    size: number | string;
}
interface IAudioProps {
    uploader: (file: File, editor: SylApi) => Promise<{
        src: string;
        width?: number;
        height?: number;
        [key: string]: any;
    }>;
    uploadBeforeInsert?: boolean;
    addAttributes?: IUserAttrsConfig;
    accept?: string;
    isInline?: boolean;
}
declare class AudioController extends SylController<IAudioProps> {
    name: string;
    private input;
    uploader: IAudioProps['uploader'];
    constructor(editor: SylApi, props: IAudioProps);
    private onChange;
    toolbar: {
        icon: string;
        handler: (editor: SylApi) => void;
    };
    editorWillUnmount: () => void;
}
declare class Audio extends BlockAtom<IAudioAttrs> {
    props: IAudioProps;
    constructor(editor: SylApi, props: IAudioProps);
    name: string;
    parseDOM: {
        tag: string;
        getAttrs: (dom: HTMLAudioElement) => false | {
            src: string;
            title: string;
            type: undefined;
            size: string | number;
        };
    }[];
    attrs: {
        src: {
            default: string;
        };
        type: {
            default: string;
        };
        title: {
            default: string;
        };
        size: {
            default: number;
        };
    };
    toDOM: (node: Node) => DOMOutputSpec;
}
declare class AudioPlugin extends SylPlugin<IAudioProps> {
    name: string;
    Controller: typeof AudioController;
    Schema: typeof Audio;
}
export { Audio, AudioController, AudioPlugin, IAudioAttrs, IAudioProps };
