import { BlockAtom, SylApi, SylController, SylPlugin } from '@syllepsis/adapter';
import { DOMOutputSpecArray, Node } from 'prosemirror-model';
import { IUserAttrsConfig } from '../../utils';
interface IVideoProps {
    uploader: (file: File, editor: SylApi) => Promise<{
        src: string;
        width?: number;
        height?: number;
        [key: string]: any;
    }>;
    accept?: string;
    addAttributes?: IUserAttrsConfig;
    uploadBeforeInsert?: boolean;
    isInline?: boolean;
}
interface IVideoAttrs {
    src: string;
    width: string | number;
    height: string | number;
}
declare class VideoController extends SylController<IVideoProps> {
    fileInput: HTMLInputElement;
    toolbar: {
        icon: string;
        handler: () => void;
    };
    uploadVideo: IVideoProps['uploader'];
    constructor(editor: SylApi, props: IVideoProps);
    onChange: (e: Event) => Promise<void>;
    editorWillUnmount: () => void;
}
declare class Video extends BlockAtom<IVideoAttrs> {
    props: IVideoProps;
    constructor(editor: SylApi, props: IVideoProps);
    name: string;
    attrs: {
        src: {
            default: string;
        };
        width: {
            default: number;
        };
        height: {
            default: string;
        };
    };
    parseDOM: ({
        tag: string;
        getAttrs: (dom: HTMLParagraphElement) => boolean;
    } | {
        tag: string;
        getAttrs: (dom: HTMLVideoElement) => false | {
            src: string;
            width: number | undefined;
            height: number | undefined;
        };
    })[];
    toDOM: (node: Node) => DOMOutputSpecArray;
}
declare class VideoPlugin extends SylPlugin<IVideoProps> {
    name: string;
    Controller: typeof VideoController;
    Schema: typeof Video;
}
export { IVideoAttrs, IVideoProps, Video, VideoController, VideoPlugin };
