import { Block, SylApi, SylController, SylPlugin } from '@syllepsis/adapter';
import { DOMOutputSpecArray, Node as ProseMirrorNode, Slice } from 'prosemirror-model';
import { EditorState, Transaction } from 'prosemirror-state';
import { EditorView } from 'prosemirror-view';
import { constructTypesetParseDOM, ITypesetProps, IUserAttrsConfig } from '../../utils';
import { LIST_ITEM_NAME } from './const';
declare module '@syllepsis/adapter' {
    interface ISylApiCommand {
        list_item?: {
            getMaxNestedLevel: () => number;
            setMaxNestedLevel: (level: number) => void;
            liftItem: () => void;
            sinkItem: () => void;
        };
    }
}
interface IListItemProps extends Omit<ITypesetProps, 'allowedLineIndents'> {
    matchInnerTags?: string[];
    addAttributes?: IUserAttrsConfig;
    maxNestedLevel?: number;
}
interface IListItemAttrs {
    align: string;
    spaceBefore: number | string;
    spaceAfter: number | string;
    spaceBoth: number | string;
    lineHeight: number | string;
}
declare class ListItem extends Block<IListItemAttrs> {
    formatAttrs: ReturnType<typeof constructTypesetParseDOM>['formatAttrs'];
    defaultFontSize: number;
    toDOMAttrs: {};
    constructor(editor: SylApi, props: IListItemProps);
    constructParseDOM(config: IListItemProps): void;
    name: string;
    tagName: () => string;
    attrs: {
        align: {
            default: string;
        };
        spaceBefore: {
            default: string;
        };
        spaceAfter: {
            default: string;
        };
        spaceBoth: {
            default: string;
        };
        lineHeight: {
            default: string;
        };
    };
    inline: boolean;
    defining: boolean;
    parseDOM: {
        tag: string;
        priority: number;
        getAttrs: (dom: HTMLElement) => false | {
            [x: string]: any;
            align?: "center" | "left" | "right" | "justify" | undefined;
            spaceBefore?: number | undefined;
            spaceAfter?: number | undefined;
            spaceBoth?: number | undefined;
            lineHeight?: number | undefined;
            lineIndent?: number | undefined;
        };
    }[];
    toDOM: (node: ProseMirrorNode) => DOMOutputSpecArray;
}
declare class ListItemController extends SylController<IListItemProps> {
    name: string;
    eventHandler: {
        transformPasted: (editor: SylApi, slice: Slice) => Slice<any>;
    };
    command: {
        getMaxNestedLevel: () => number | undefined;
        setMaxNestedLevel: (editor: SylApi, level: number) => number;
        liftItem: (editor: SylApi) => boolean;
        sinkItem: (editor: SylApi) => boolean;
    };
    keymap: {
        Enter: (editor: SylApi, state: EditorState<any>, dispatch?: ((tr: Transaction<any>) => void) | undefined) => boolean;
        'Shift-Tab': (editor: SylApi, state: EditorState<any>, dispatch?: ((tr: Transaction<any>) => void) | undefined) => boolean;
        Tab: (editor: SylApi, state: EditorState, dispatch: EditorView['dispatch']) => boolean;
        Backspace: (editor: SylApi, state: EditorState<any>, dispatch?: ((tr: Transaction<any>) => void) | undefined) => boolean;
    };
    appendTransaction: (tr: Transaction) => Transaction<any> | undefined;
}
declare class ListItemPlugin extends SylPlugin<IListItemProps> {
    name: string;
    Controller: typeof ListItemController;
    Schema: typeof ListItem;
}
export { LIST_ITEM_NAME, ListItem, ListItemController, ListItemPlugin };
