import { BlockAtom, SylApi, SylController, SylPlugin } from '@syllepsis/adapter';
import { DOMOutputSpecArray, Node, Node as ProsemirrorNode } from 'prosemirror-model';
import { EditorView } from 'prosemirror-view';
import { ImageAttrs, ImageProps, IUpdateImageProps } from './types';
declare class ImageController extends SylController<ImageProps> {
    fileInput: HTMLInputElement;
    toolbar: {
        className: string;
        tooltip: string;
        icon: any;
        handler: () => void;
    };
    constructor(editor: SylApi, props: ImageProps);
    command: {
        insertImages: (editor: SylApi, files: File[]) => Promise<void>;
        updateImageUrl: (editor: SylApi, props: IUpdateImageProps) => Promise<void>;
        getConfiguration: () => Partial<ImageProps>;
    };
    eventHandler: {
        handleClickOn(editor: SylApi, view: EditorView, pos: number, node: ProsemirrorNode, nodePos: number, event: MouseEvent): boolean;
        handlePaste: (editor: SylApi, view: EditorView, e: Event) => boolean;
        handleDOMEvents: {
            drop: (editor: SylApi, view: EditorView, e: Event) => boolean;
        };
    };
    editorWillUnmount: () => void;
}
declare class Image extends BlockAtom<ImageAttrs> {
    props: ImageProps;
    name: string;
    traceSelection: boolean;
    constructor(editor: SylApi, props: ImageProps);
    parseDOM: ({
        tag: string;
        getAttrs: (dom: HTMLElement) => false | ImageAttrs;
    } | {
        tag: string;
        getAttrs: (dom: HTMLImageElement) => false | {
            src: string;
            alt: string;
            name: string;
            align: any;
            width: number;
            height: number;
        };
    })[];
    toDOM: (node: Node) => DOMOutputSpecArray;
    attrs: {
        src: {
            default: string;
        };
        alt: {
            default: string;
        };
        name: {
            default: string;
        };
        width: {
            default: number;
        };
        height: {
            default: number;
        };
        align: {
            default: "center";
        };
    };
}
declare class ImagePlugin extends SylPlugin<ImageProps> {
    name: string;
    Controller: typeof ImageController;
    Schema: typeof Image;
}
export { Image, ImageAttrs, ImageController, ImagePlugin, ImageProps };
