"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackgroundPlugin = exports.BackgroundController = exports.Background = void 0;
var adapter_1 = require("@syllepsis/adapter");
var utils_1 = require("../../utils");
var colorReg = /^\s*(rgba\([^)]+\)|rgb\([^)]+\)|#[\d|a-f]{3,8})|\w*/i;
var NAME = 'background';
var getBgAttrs = function (style, transparent) {
    var colorMatch = style.match(colorReg);
    if (!colorMatch)
        return false;
    var background = (0, utils_1.toHex)(colorMatch[0], transparent);
    if (background) {
        return {
            color: background,
        };
    }
    return false;
};
var Background = /** @class */ (function (_super) {
    __extends(Background, _super);
    function Background(editor, props) {
        var _this = _super.call(this, editor, props) || this;
        _this.name = NAME;
        _this.tagName = function () { return 'span'; };
        _this.attrs = {
            color: {
                default: '#FFFFFF',
            },
        };
        _this.getAttrs = function (style) { return getBgAttrs(style, _this.props.transparent); };
        _this.parseDOM = [
            {
                style: 'background',
                getAttrs: _this.getAttrs,
            },
            {
                style: 'background-color',
                getAttrs: _this.getAttrs,
            },
        ];
        _this.toDOM = function (node) {
            var _a;
            var color = node.attrs.color;
            var renderColor = color && (0, utils_1.toHex)(color) !== (0, utils_1.toHex)(_this.attrs.color.default) && color;
            return [
                'span',
                renderColor ? { style: "background-color: " + node.attrs.color + ";" } : (_a = {}, _a[adapter_1.IG_TAG] = 'true', _a),
                0,
            ];
        };
        if (props.transparent !== false) {
            _this.props.transparent = true;
        }
        if (props.default) {
            _this.attrs.color.default = (0, utils_1.toHex)(props.default, _this.props.transparent);
        }
        return _this;
    }
    return Background;
}(adapter_1.Inline));
exports.Background = Background;
var BackgroundController = /** @class */ (function (_super) {
    __extends(BackgroundController, _super);
    function BackgroundController(editor, props) {
        var _this = _super.call(this, editor, props) || this;
        _this.name = 'background';
        _this.defaultColor = '#FFFFFF';
        _this.getAttrs = function (color) {
            var result = (0, utils_1.toHex)(color);
            if (!result)
                return false;
            return {
                color: result,
            };
        };
        _this.getValue = function (attrs) { return attrs.color; };
        _this.toolbar = {
            className: 'background',
            tooltip: 'background-color',
        };
        _this.disable = function (editor) { return (0, utils_1.checkMarkDisable)(editor.view, NAME); };
        if (props.default) {
            _this.defaultColor = (0, utils_1.toHex)(props.default);
        }
        return _this;
    }
    return BackgroundController;
}(adapter_1.SylController));
exports.BackgroundController = BackgroundController;
var BackgroundPlugin = /** @class */ (function (_super) {
    __extends(BackgroundPlugin, _super);
    function BackgroundPlugin() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.name = NAME;
        _this.Controller = BackgroundController;
        _this.Schema = Background;
        return _this;
    }
    return BackgroundPlugin;
}(adapter_1.SylPlugin));
exports.BackgroundPlugin = BackgroundPlugin;
//# sourceMappingURL=index.js.map