import { Inline, SylApi, SylController, SylPlugin } from '@syllepsis/adapter';
import { DOMOutputSpec, Node } from 'prosemirror-model';
import { getFormatAttrsByValue, TAllowedValuesConfig, TValuesConfig } from '../../utils';
interface IFontSizeProps {
    allowedValues?: TAllowedValuesConfig;
    values?: TValuesConfig;
    defaultFontSize?: number;
    unit?: 'em' | 'px';
}
interface IFontSizeAttrs {
    size: string | number;
}
declare class FontSize extends Inline<IFontSizeAttrs> {
    name: string;
    tagName: () => string;
    allowedValues: number[];
    formatAttrs: ReturnType<typeof getFormatAttrsByValue>['formatAttrs'];
    defaultFontSize: number;
    constructor(editor: SylApi, props: IFontSizeProps);
    constructParseDOM(config?: IFontSizeProps): void;
    attrs: {
        size: {
            default: string;
        };
    };
    parseDOM: {
        style: string;
        getAttrs: (_style: string) => false | {
            [x: string]: string | number | undefined;
        };
    }[];
    toDOM: (node: Node) => DOMOutputSpec;
}
declare class FontSizeController extends SylController<IFontSizeProps> {
    name: string;
    fontSize: number;
    constructor(editor: SylApi, props: IFontSizeProps);
    constructValue: (props: any) => void;
    toolbar: {
        className: string;
        tooltip: string;
        type: string;
        icon: (editor: SylApi, attrs: {
            size: number;
        }) => number;
        value: ({
            text: string;
            attrs: {
                size: number;
            };
        } | {
            text: string;
            attrs: boolean;
        })[];
    };
}
declare class FontSizePlugin extends SylPlugin<IFontSizeProps> {
    name: string;
    Controller: typeof FontSizeController;
    Schema: typeof FontSize;
}
export { FontSize, FontSizeController, FontSizePlugin };
