"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.FontSizePlugin = exports.FontSizeController = exports.FontSize = void 0;
var adapter_1 = require("@syllepsis/adapter");
var utils_1 = require("../../utils");
var PLUGIN_NAME = 'font_size';
var FontSize = /** @class */ (function (_super) {
    __extends(FontSize, _super);
    function FontSize(editor, props) {
        var _this = _super.call(this, editor, props) || this;
        _this.name = PLUGIN_NAME;
        _this.tagName = function () { return 'span'; };
        _this.allowedValues = [];
        _this.formatAttrs = function (v) { return v; };
        _this.defaultFontSize = 16;
        _this.attrs = {
            size: {
                default: '',
            },
        };
        _this.parseDOM = [
            {
                style: 'font-size',
                getAttrs: function (_style) {
                    var size = _style;
                    if (size === 'medium') {
                        return false;
                    }
                    else if (size === 'small' && _this.allowedValues.length) {
                        size = _this.allowedValues[0];
                    }
                    else if (size === 'large' && _this.allowedValues.length) {
                        size = _this.allowedValues[_this.allowedValues.length - 1];
                    }
                    else if (!Number.isNaN((0, adapter_1.getPx)(size, _this.defaultFontSize))) {
                        size = (0, adapter_1.getPx)(size, _this.defaultFontSize);
                    }
                    if (!size)
                        return false;
                    return _this.formatAttrs({
                        size: size,
                    });
                },
            },
        ];
        _this.toDOM = function (node) {
            var size = node.attrs.size;
            var attrs = {};
            if (size) {
                if (Number.isNaN(parseInt(size, 10))) {
                    attrs.style = "font-size: " + size + ";";
                }
                else if (_this.props.unit === 'px') {
                    attrs.style = "font-size: " + (0, utils_1.getFixSize)(size) + "px;";
                }
                else {
                    attrs.style = "font-size: " + (0, utils_1.getFixSize)(size / _this.defaultFontSize) + "em;";
                }
            }
            else {
                attrs[adapter_1.IG_TAG] = 'true';
            }
            return ['span', attrs, 0];
        };
        _this.constructParseDOM(props);
        return _this;
    }
    FontSize.prototype.constructParseDOM = function (config) {
        if (!config)
            return;
        if (!config.allowedValues)
            return;
        var _a = (0, utils_1.getFormatAttrsByValue)(config.allowedValues, 'size'), formatAttrs = _a.formatAttrs, values = _a.values, defaultValue = _a.defaultValue;
        if (defaultValue !== undefined) {
            this.defaultFontSize = +defaultValue;
        }
        if (values)
            this.allowedValues = values;
        this.formatAttrs = formatAttrs;
    };
    return FontSize;
}(adapter_1.Inline));
exports.FontSize = FontSize;
var FontSizeController = /** @class */ (function (_super) {
    __extends(FontSizeController, _super);
    function FontSizeController(editor, props) {
        var _this = _super.call(this, editor, props) || this;
        _this.name = PLUGIN_NAME;
        _this.fontSize = 16;
        _this.constructValue = function (props) {
            if (props.values) {
                _this.toolbar.value = (0, utils_1.formatMenuValues)('size', props.values);
            }
        };
        _this.toolbar = {
            className: PLUGIN_NAME,
            tooltip: PLUGIN_NAME,
            type: 'select',
            icon: function (editor, attrs) {
                if (attrs.size)
                    return attrs.size;
                else
                    return _this.fontSize;
            },
            value: [
                {
                    text: '12',
                    attrs: {
                        size: 12,
                    },
                },
                {
                    text: '16',
                    attrs: false,
                },
                {
                    text: '20',
                    attrs: {
                        size: 20,
                    },
                },
            ],
        };
        _this.constructValue(props);
        if (props.allowedValues) {
            var allowedValues = props.allowedValues;
            if (!Array.isArray(allowedValues))
                allowedValues = [allowedValues];
            allowedValues.some(function (val) {
                if (typeof val === 'object' && val.default) {
                    _this.fontSize = val.value;
                    return true;
                }
                return false;
            });
        }
        return _this;
    }
    return FontSizeController;
}(adapter_1.SylController));
exports.FontSizeController = FontSizeController;
var FontSizePlugin = /** @class */ (function (_super) {
    __extends(FontSizePlugin, _super);
    function FontSizePlugin() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.name = PLUGIN_NAME;
        _this.Controller = FontSizeController;
        _this.Schema = FontSize;
        return _this;
    }
    return FontSizePlugin;
}(adapter_1.SylPlugin));
exports.FontSizePlugin = FontSizePlugin;
//# sourceMappingURL=index.js.map