import { ITypesetAttrs, Types } from '@syllepsis/adapter';
import { AttributeSpec } from 'prosemirror-model';
interface IDefaultConfig<T = number> {
    value: T;
    default: boolean;
}
declare type TAllowedValueConfig<T = number> = T | IDefaultConfig<T>;
declare type TAllowedValuesConfig<T = number> = Array<TAllowedValueConfig<T>> | IDefaultConfig | false;
declare type TValueConfig = number | {
    value?: number;
    default?: boolean;
    attrs?: Types.StringMap<any>;
    text?: any;
};
declare type TValuesConfig = Array<TValueConfig>;
interface ITypesetProps {
    defaultFontSize?: number;
    allowedAligns?: TAllowedValuesConfig<string>;
    allowedLineHeights?: TAllowedValuesConfig;
    allowedLineIndents?: TAllowedValuesConfig;
    allowedSpaceBefores?: TAllowedValuesConfig;
    allowedSpaceAfters?: TAllowedValuesConfig;
    allowedSpaceBoths?: TAllowedValuesConfig;
}
declare const getNestedValue: (val: number, valAllowed: Array<string | number> | false) => string | number | undefined;
declare const getFormatAttrsByValue: (allowedValues: TAllowedValuesConfig, attrName: string) => {
    formatAttrs: (_attrs: Types.StringMap<any>) => false | {
        [x: string]: string | number | undefined;
    };
    values: false | (string | number)[];
    defaultValue: string | number | undefined;
};
/**
 * analysis of attrs for constructing typesetting
 * @param config ITypesetProps
 * @returns {number} defaultFontSize default font size, used to transform
 * @returns {Function} formatAttrs used to format and output `attrs` according to config
 * @returns {Object} defaultAttrs new default `attrs` constructed according to config
 */
declare const constructTypesetParseDOM: (config: ITypesetProps) => {
    defaultFontSize: number;
    formatAttrs: (nodeAttrs: ITypesetAttrs & Types.StringMap<any>, dom?: HTMLElement | undefined) => {
        [x: string]: any;
        align?: "center" | "left" | "right" | "justify" | undefined;
        spaceBefore?: number | undefined;
        spaceAfter?: number | undefined;
        spaceBoth?: number | undefined;
        lineHeight?: number | undefined;
        lineIndent?: number | undefined;
    };
    defaultAttrs: Partial<{
        align?: AttributeSpec | undefined;
        spaceBefore?: AttributeSpec | undefined;
        spaceAfter?: AttributeSpec | undefined;
        spaceBoth?: AttributeSpec | undefined;
        lineHeight?: AttributeSpec | undefined;
        lineIndent?: AttributeSpec | undefined;
    } & {
        [T: string]: AttributeSpec;
    }>;
};
declare const formatMenuValues: (attrsName: string, valueConfigs?: TValuesConfig, defaultVal?: any) => {
    text: any;
    attrs: false | any;
}[];
export { constructTypesetParseDOM, formatMenuValues, getFormatAttrsByValue, getNestedValue, ITypesetProps, TAllowedValuesConfig, TValuesConfig, };
